@@ -361,13 +361,17 @@ class NoteableClient(httpx.AsyncClient):
         )
         resp.raise_for_status()
         resp_data = resp.json()
-        parameterized_notebook = NotebookFile.parse_obj(resp_data['parameterized_notebook'])
+
+        # Use .get(...) for backwards compatibility with old API which returns the NotebookFile as the response
+        parameterized_notebook = NotebookFile.parse_obj(
+            resp_data.get('parameterized_notebook', resp_data)
+        )
         parameterized_notebook.content = httpx.get(
             parameterized_notebook.presigned_download_url
         ).content.decode("utf-8")
         job_instance_attempt = (
             JobInstanceAttempt.parse_obj(resp_data['job_instance_attempt'])
-            if resp_data['job_instance_attempt']
+            if resp_data.get('job_instance_attempt')
             else None
         )
 
